.. _about:

=====
About
=====

KLIFF is the `KIM-based Learning-Integrated Fitting Framework` for interatomic
potentials.
It can be used to fit both physics-motivated potentials and machine learning
potentials like the nueral network potentials.
The trained potential can be deployed with the kim-api, which is supported by major
simulation codes such as **LAMMPS**, **ASE**, **DL_POLY**, and **GULP** among others.

